@@ -1,7 +1,11 @@
+import logging
 import os
 import zipfile
+
 import tarsafe  # type:ignore
 
+log = logging.getLogger("guarddog")
+
 
 def safe_extract(source_archive: str, target_directory: str) -> None:
     """
@@ -13,9 +17,10 @@ def safe_extract(source_archive: str, target_directory: str) -> None:
     @param target_directory:    The directory where to extract the archive to
     @raise ValueError           If the archive type is unsupported
     """
-    if source_archive.endswith('.tar.gz'):
+    log.debug(f"Extracting archive {source_archive} to directory {target_directory}")
+    if source_archive.endswith('.tar.gz') or source_archive.endswith('.tgz'):
         tarsafe.open(source_archive).extractall(target_directory)
-    elif source_archive.endswith('.zip'):
+    elif source_archive.endswith('.zip') or source_archive.endswith('.whl'):
         with zipfile.ZipFile(source_archive, 'r') as zip:
             for file in zip.namelist():
                 # Note: zip.extract cleans up any malicious file name such as directory traversal attempts
