@@ -1,7 +1,11 @@
+import logging
+
 import requests
 
+log = logging.getLogger("guarddog")
 
-def get_package_info(name) -> dict:
+
+def get_package_info(name: str) -> dict:
     """Gets metadata and other information about package
 
     Args:
@@ -16,6 +20,7 @@ def get_package_info(name) -> dict:
     """
 
     url = "https://pypi.org/pypi/%s/json" % (name,)
+    log.debug(f"Retrieving PyPI package metadata from {url}")
     response = requests.get(url)
 
     # Check if package file exists
